┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphincontroller.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphincontroller.h')
-rw-r--r--src/dolphincontroller.h13
1 files changed, 8 insertions, 5 deletions
diff --git a/src/dolphincontroller.h b/src/dolphincontroller.h
index d91e7f5c1..a7f227306 100644
--- a/src/dolphincontroller.h
+++ b/src/dolphincontroller.h
@@ -66,7 +66,8 @@ public:
void triggerActivation();
void indicateDroppedUrls(const KUrl::List& urls,
- const QModelIndex& index,
+ const KUrl& destPath,
+ const QModelIndex& destIndex,
QWidget* source);
void indicateSortingChange(DolphinView::Sorting sorting);
@@ -132,12 +133,14 @@ signals:
void activated();
/**
* Is emitted if the URLs \a urls have been dropped to the index
* \a index. \a source indicates the widget where the dragging has
* been started from.
*/
void urlsDropped(const KUrl::List& urls,
- const QModelIndex& index,
+ const KUrl& destPath,
+ const QModelIndex& destIndex,
QWidget* source);
/** Is emitted if the sorting has been changed to \a sorting. */
@@ -132,12 +133,14 @@ signals:
void activated();
/**
- * Is emitted if the URLs \a urls have been dropped to the index
- * \a index. \a source indicates the widget where the dragging has
- * been started from.
+ * Is emitted if the URLs \a urls have been dropped to the destination
+ * path \a destPath. If the URLs have been dropped above an item of
+ * the destination path, the item is indicated by \a destIndex.
+ * \a source indicates the widget where the dragging has been started from.
*/
void urlsDropped(const KUrl::List& urls,